#ifdef JFB_WITH_LIBHANGUL
#ifndef INCLUDE_HINPUT_H
#define INCLUDE_HINPUT_H
#include <hangul.h>
#include "term.h"

#define KEY_ESC 0x1B
#define KEY_SPACE 0x20
#define KEY_BACKSPACE 0x7F

enum {
	HINPUT_ENCODING_NONE,
	HINPUT_ENCODING_UTF8,
	HINPUT_ENCODING_EUCKR
};

enum { 
	ENGLISH_KEYBOARD_QWERTY,
	ENGLISH_KEYBOARD_DVORAK
};

typedef struct THinput_Raw {
	HangulInputContext *hic;
	int output_encoding;
	int preedit_encoding;

	int disable_utf8;
	int disable_euckr;
	int hangul_keyboard;
	int english_keyboard;

	unsigned int preedit_str[64]; // as defined by libhangul
#ifdef JFB_ENABLE_CURSOR_BLINK
	int cursor_blink;
#endif
} THinput;

extern THinput gHin;

void hinput_init(THinput *h);
void hinput_print_status(THinput *h);
int hinput_read_encoding(char *enc);
void hinput_change_output_encoding(THinput *h, int output_encoding);
void hinput_change_preedit_encoding(THinput *h, int preedit_encoding);
int hinput_read_disable(char *disable);
void hinput_disable_utf8(THinput *h, int disable);
void hinput_disable_euckr(THinput *h, int disable);
int hinput_read_hangul_keyboard(char *hkbd);
void hinput_change_hangul_keyboard(THinput *h, int hangul_keyboard);
int hinput_read_english_keyboard(char *ekbd);
void hinput_change_english_keyboard(THinput *h, int english_keyboard);

void hinput_exit(THinput *h);
void hinput_exit_at_exit(void);
void hinput_try_commit(TTerm *p, THinput *h);
void hinput_try_preedit(TTerm *p, THinput *h);
int hinput_process(TTerm *p, THinput *h, u_char *buf, int ret);
#endif /* INCLUDE_HINPUT_H */
#endif /* JFB_WITH_LIBHANGUL */
